# Sistema de gestión de Cookies via parametro

> **Aclaración:** esta funcionalidad se ejecuta momentaneamente a traves del servicio de parametros, pero se la deja preparada para que en un futuro pueda recibir un JSON con los datos necesarios para su completa ejecución. 

## Contenido
- [Introducción](#introducción)
- [Configuración de Parámetros](#configuración-de-parámetros)
- [Parámetros](#parámetros)
    - [Profundizando en algunos parámetros](#profundizando-en-algunos-parámetros)
        - [cookies_format](#cookies_format)
        - [cookies_others_](#cookies_others_)
        - [cookies_cookies_](#cookies_cookies_)
        - [cookies_linkRedirect](#cookies_linkredirect)
    - [Algunas cosas a saber](#algunas-cosas-a-saber)


## Introducción 
En este documento se va a explicar como funciona el servicio de cookies y como el mismo se configura a través del servicio de parametros.
Primero se explicara como se deben cargar los parametros en el backoffice, que reglas deben seguir, que valores deben contener, etc.


## Configuración de Parámetros

Los parámetros en el backoffice se deberán cargar de la siguiente forma:
- Deben comenzar con `cookies_`, esto le indicara al servicio que tiene que guardar ese parámetro.
- El segundo nombre hara referencia a un atributo especifico, este, como se vera mas abajo, si es unico solo va su nombre mientras que si contiene otros datos se le debera agregar un _ al finalizar su nombre.
- El caso de exitir más información despues del segundo nombre esta debera contener - entre sus partes. 

Ejemplo: `cookies_[nombre]_[mas-texto]`

## Parámetros
Veamos los parámetros que se pueden cargar para configurar las cookies

| Nombre | Funcionalidad | Valores |
| ------ | ------------- | ------- |
| `cookies_format` | Configura el formato en el que se mostrara en el frontend el componente de cookies. Este formato puede ser un **sidebar**, un **modal** o un **toast** | Su primer contenido debe ser el nombre del formato que se quiere usar. Ej: `sidebar`. |
| `cookies_message` | Mesaje que se mostrara al levantar el componente de cookies | Un texto, pueden contener *[]* para encerrar un link. | 
| `cookies_linkRedirect` | Contiene el path del link contenido en el mensaje entre *[]*. Este valor sera incluido dentro del atributo href en la etiqueta `<a>` | Una path valido a donde se quiera redirigir |
| `cookies_cookies_[nombre-de-la-cookie]` | Contiene la cookie que se quiere guardar, el nombre (de ser varias palabras) debe estar separado por **-**. | Debe guardar el mensaje que se quiere mostrar para esa cookie. |
| `cookies_others_[nombre-especifico]` | Se utiliza para todo lo referido a la configuración de los botones | El valor sera el nombre del botón a mostrar. | 
| `cookies_title` | Se utiliza para añadirle un titulo al mensaje principal. | Una cadena de texto. |

### Profundizando en algunos parámetros.
Pasaremos a explicar algunos parárametros especificos que necesitan seguir ciertas reglas. 
#### **cookies_format**
Para habilitar el `sidebar` esta última palabra debera ser la primera que se agrega en el input de valores. Posteriormente la pueden seguir las siguientes palabras claves separadas por un espacion en blanco. 

| Palabra | ¿Para que sirve? |
| ------- | ---------------- |
| `backdrop` | Le agrega un fondo transparente oscuro al mensaje del sidebar |
| `scroll` | Permite scrolear la pagina mientras esta presente el sidebar |
| `top` | El sidebar se muestra en la parte superior de la página |
| `bottom` | El sidebar se muestra en la parte inferior de la página |
| `start` | El sidebar se muestra en la parte izquierda de la página |
| `end` | El sidebar se muestra en la parte derecha de la página |

> *Las palabras top, bottom, start y end solo debe ir una de ellas.* 

Ejemplo:
```
sidebar start backdrop scroll
```

Para habilitar el `modal` esta última palabra debera ser la primer que se agrega en el input de valores. Al igual que sidebar tiene palabras claves que deben ir separadas por un espacio en blanco.

| Palabra | ¿Para que sirve? |
| ------- | ---------------- |
| `xl` | Tamaño extra large del modal | 
| `lg` | Tamaño large del modal | 
| `sm` | Tamaño small del modal |

> *Solo una de estas 3 opciones debe ir presente* 

Ejemplo:
```
modal lg
```

Para habilitar el `toast` esta última palabra debera ser la primera que se agrega en el input de valores. Tambien posee palabras claves extras que deben ir separadas por un espacio en blanco. 

| Palabra | ¿Para que sirve? |
| ------- | ---------------- |
| `start-0` | Lado izquierdo |
| `start-50` | Centro horizontal |
| `end-0` | Lado derecho | 

> *Solo una de estas 3 opciones debe ir presente*

| Palabra | ¿Para que sirve? |
| ------- | ---------------- |
| `top-0` | Parte superior |
| `top-50` | Centro vertical | 
| `bottom-0` | Parte inferior |

> *Solo una de estas 3 opciones debe ir presente*

Ejemplo: 
```
toast top-0 end-0
```
*En este ejemplo se ubicaria en la parte superior de la pagina, del lado derecho.*

> **Para tener en cuenta:** el toast es solo un cartel informativo, es decir que no tiene los botones de aceptar cookies, ni de configuración. Asi que deberia ser utilizado cuando si o si se van a guardar cookies a modo de aviso. 

#### **cookies_others_[...]**
En cookies_others se ubican basicamente la configuracion a lo que a botones respecta, mas que nada su nombre. 

Palabras claves que se deben usar:
| Palabra | Botón Referenciado | 
| ------- | ------------------ |
| `btnConfig` | Botón para acceder al modal de configuración | 
| `btnAccept` | Botón para aceptar las cookies | 
| `btnSave` | Botón para guardar la configuración de las cookies de ser aceptadas | 
| `btnAll` | Botón para guardar todas las cookies antes de ser aceptadas |

Ejemplo del nombre del parámetro:
```
cookies_other_btnAccept
```
Y en su valor podría un texto como por ejemplo *Aceptar las cookies* 

#### **cookies_cookies_[...]** 
En cookies_cookies van a ir las cookies que se quiera guardar, con su texto adicional.
El nombre de las cookies debe estar separado por *-* (guión alto).

Ejemplo del nombre del parámetro:
```
cookies_cookies_analytics-gtm
```
Y un valor de ejemplo podría ser *Estas cookies guardan información para...*. 

> :warning: *Si no hay ningun parámetro cookie_cookie_[...] el botón de* **configuración no estara presente**.

#### **cookies_linkRedirect**
Como se menciono más arriba, este parámetro debe contener el link al que se quiere redireccionar como por ejemplo en *Politicas de Privacidad*. Para hacer referencia a este link en el parámetro `cookies_message` donde cargamos el texto principal, debemos encerrar con **[ ]** (corchetes) lo que querramos que sea parte de ese link. 

Ejemplo del texto cargado en `cookies_message`:
```
... puede consultar nuestas [Políticas de Privacidad].
```
Esto se mostrara de la siguente forma:
> ... puede consultar nuestras [Políticas de Privacidad](#).

Y el código en HTML será:
```html
<p>... puede consultar nuestras <a href="/link_del_parametro_linkRedirect"> Políticas de Privacidad </a></p>.
```

### Algunas cosas a saber
Estas son algunas de las cosas que deben saber o al menos tener en cuenta:
- Tanto el sidebar, modal y toast son sloteables desde el frontend, es decir que se puede agregar un diseño mas personalizado y reemplazar el que esta en el core, pero esto ya queda del lado de frontend.
- El modal de configuración no tiene otra variante, es decir siempre es un modal. Tambien es sloteable desde el frontend.
- Todos los componentes tienen sus clases para el manejo de estilos desde el frontend.
- Si no se carga el parámetro `cookies_format` por defecto se mostrara un sidebar.
- Siempre se guarda una cookie que es la que controla si se aceptaron la/s misma/s. Una vez aceptadas el cartel de cookies no será visible hasta que no sean borradas del navegador.
- El tiempo de vida de las cookies son de 30 dias, esto no es editable por el momento hasta no encontrarle una logica a dicho funcionamiente.
- Las cookies siempre se guardan con un valor `true`.

> **Nota:** Esta es la primer version, se hizo foco en la funcionalidad dejando el diseño en segundo plano, por lo que queda a la espera de futuros cambios. 