import { OnInit } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { ComponentHelper } from '../../classes/component-helper';
import { Constants } from '../../core.consts';
import { FilterStep } from '../../interfaces/filterStep';
import { ConcatenatedAssociationsService } from '../../services/concatenated-associations.service';
import { OptionsService } from '../../services/options.service';
import { ProductsService } from '../../services/products/products.service';
import { ToastService } from '../../utils/toast.service';
import { CartService } from '../../services/cart.service';
import { Router } from '@angular/router';
export declare class BuildYourEcComponent extends ComponentHelper implements OnInit {
    private concatenated;
    protected optionsService: OptionsService;
    productsService: ProductsService;
    formBuilder: FormBuilder;
    protected toastrService: ToastService;
    consts: Constants;
    cartService: CartService;
    router: Router;
    currentPosition: number;
    private code;
    private selectedValues;
    taxonCode: number;
    stepList: FilterStep[];
    currentStep: any;
    itemCurrentSelected: string;
    loadingStep: Boolean;
    finished: Boolean;
    noMoreCoincidences: Boolean;
    products: any[];
    error: any;
    total: Array<any>;
    /**
     * @description Arreglo de funciones para ejecutarse al terminar la carga de pasos.
     * El objeto se arma { function: [Function] , args: [Argumentos] }
     */
    functionsToNextStep: any[];
    functionsToPrevStep: any[];
    attributes: Array<any>;
    values: Array<any>;
    constructor(concatenated: ConcatenatedAssociationsService, optionsService: OptionsService, productsService: ProductsService, formBuilder: FormBuilder, toastrService: ToastService, consts: Constants, cartService: CartService, router: Router);
    /**
     * @description inserta atributos adicionales a los pasos recibidos.
     * current => para indicar cuando el paso esta activo.
     * touched => para indicar cuando el paso fue activado.
     */
    insertAttributes: () => void;
    /**
     * @description retorna las opciones del paso segun el tipo de paso que esta recibiendo.
     * @param item step para obtener los datos.
     */
    itemValuesFactory: (item: FilterStep) => void;
    /**
     * @description retorna los valores del filtro segun el tipo.
     * @param item filtro
     * @returns retorna un arreglo con las opciones del filtro.
     */
    getValuesByFilter: (item: FilterStep) => any[];
    /**
     * @description cambia el contenido de los valores de los filtros, segun el tipo de filtro.
     * @param item filtro
     * @param values arreglo con los valores de las opciones
     */
    setValuesByFilter: (item: FilterStep, values: any) => void;
    ngOnInit(): void;
    /**
     * @description Carga el componente para obtener sus datos iniciales.
     * @param section Seccion asociada con la asociaciones creadas
     * @param fatherCode Codigo del paso de donde se quiere arrancar el filtrado.
     */
    load: (section?: string, fatherCode?: string) => void;
    /**
     * @description carga con el valor seleccionado. Reinicia la condicion de "no más coincidencias"
     * @param value
     */
    setItemCurrentSelected: (value: any) => void;
    /**
     * @description funcion para ser utilizada como captura del envio de un formulario.
     * @param event
     */
    submitNext: (event: any) => void;
    /**
     * @description evalua el valor que recibe por parametro, realiza la consulta para el filtrado y carga los datos recibidos.
     * @param selectValue valor asociado al codigo de la opcion elegida.
     */
    next: (selectValue?: any) => void;
    /**
     * @description realiza el transpaso de datos desde el paso actual al siguiente paso de filtrado.
     * @param selectValue valor asociado al codigo de la opcion elegida.
     */
    private setNextStep;
    /**
     * @description realiza las configuraciones necesarias para el retroceso de un paso.
     * @param index cantidad de pasos que se quiere retroceder, 1 por defecto.
     */
    prev: (index?: number) => void;
    /**
     * @description limpia los pasos, volviendo sus valores a los iniciales.
     * Elimina los valores del arreglo de valores seleccionados.
     * @param index
     */
    private clearItems;
    /**
     * @description retorna los datos de los valores de las opciones
     * @param code codigo de la opcion elegida
     * @param item filtro/paso
     * @returns los valores asociados a la opcion elegida
     */
    private getAssociatedData;
    /**
     * @description actualiza la lista de pasos.
     * @param list
     */
    updateList: (list: any) => void;
    /**
     * @description Ejecuta las funciones que se deben realizar al finalizar el proceso de un paso.
     * @param typeStep
     */
    executeFunctions: (typeStep?: string) => void;
    filtrar(code: any): void;
}
