export declare type FilterShape = 'color' | 'text' | 'size';
export declare type FilterType = 'category' | 'attributes' | 'sort' | 'dynamics' | 'all';
export declare type ElementType = 'sub' | 'child';
export interface FilterElement {
    title: string;
    type: ElementType;
    code: string;
    multi?: boolean;
    children?: FilterElement[];
    shape?: FilterShape;
    noUrl?: boolean;
    value?: string;
    selected?: boolean;
}
export interface IFilter {
    generated_url: string;
    data: any;
    type(): FilterType;
    setContent(options: any): void;
    getContent(): FilterElement[];
    setSelected(element: FilterElement, value: string): any;
    toUrlParams(): string;
}
/**
 * @description Interfaz utilizada para aplicar filtros por defecto.
 */
export declare type DefaultFilter = {
    /**
     * @descrition Tipo de filtro que se aplicara.
     * Ejemplo: 'sort' | 'category' | 'attributes' | 'dynamics' ...
     */
    filter_type: FilterType;
    /**
     * @description Contiene los codigos de los filtros que se desean aplicar.
     * Ejemplo: si el filtro es 'sort' el arreglo podria contener 'price chip' | 'price expensive' | 'alpha asc' | 'alpha desc' ...
     */
    codes: string[];
};
/**
 * @description Interfaz ultilizada para configurar los filtros
 */
export declare type FilterConfig = {
    defaultFilters?: DefaultFilter[];
    /**
     * @description Estos son los filtros que por lo general se van a mostrar en la seccion collection.
     * El orden en que se cargan las claves de los tipos de filtros influye en como se veran en la vista.
     * Ej: ['attrubutes','category'] => solo muestra estos 2 filtros siendo el de atributos el primero y
     * luego el de categorias.
     */
    filters?: FilterType[];
};
