import { Injector } from '@angular/core';
import { Cookies } from '../interfaces/cookies';
export declare class CookiesService {
    private injector;
    private cookiesSubject;
    private readySubject;
    ready$: import("rxjs").Observable<Boolean>;
    cookies$: import("rxjs").Observable<Cookies>;
    private cookiesParameters;
    private cookies;
    private defaultValues;
    constructor(injector: Injector);
    /**
     * @description retorna la *cookie* si la encuentra, *false* en caso contrario
     * @param name nombre de la cookie a buscar
     * @returns objecto | false
     */
    private getCookie;
    /**
     * @description Construye el objeto que sera utilizado para manejar las cookie.
     * Utiliza el servicio de parametros para tomar los datos que iran llenando el objeto.
     */
    private buildObject;
    /**
     * @description realiza un merge con los valores por defecto para rellenar el objeto de cookies
     */
    private setDefaultParameters;
    /**
     * @description procesa el parametro ingresado, para transformarlo en un atributo del objeto de cookies.
     * @param cookiesParameters arreglo proveniente del servicio de parametros que contiene
     * los elementos a transformar en atributos.
     */
    private processingCookieParameters;
    /**
     * @description Procesa el atributo message (*cookies_message*)
     * @param data Objeto parametro
     * @returns {string} el mensaje formateado
     */
    private messageAttrProcessing;
    /**
     * @description Procesa la cadena de string del atributo format
     * @param data Datos a ser procesados, objeto del parametro.
     * @returns El objecto formateado en un JSON.
     */
    private formatAttrProcessing;
    /**
     * @description Le da formato al atributo format de acuerdo al tipo ingresado por parametro (sidebar | modal | toast)
     * @param type 'sidebar' | 'modal' | 'toast'
     * @param value el valor de ese atributo.
     * @returns el objeto formateado.
     */
    private getObjByFormatType;
    /**
     * @description Procesa el objeto parametro, utilizando parte del codigo (a partir del segundo '_') para
     * el titulo y su valor para el mensaje.
     * @param data Datos a ser procesados, objeto parametro
     * @returns El objecto formateado en un JSON.
     */
    private cookiesAttrProcessing;
    /**
     * @description Procesa las configuraciones que vienen para el atributo others
     * @param data Datos a ser procesados, objeto parametro
     * @returns Un JSON { clave: valor } para ser añadido al objeto "others"
     */
    private othersAttrProcessing;
}
