import { Injector } from '@angular/core';
import { ConnectionService } from '../api/connection.service';
import { Constants } from '../core.consts';
import { CurrencyConfig } from '../interfaces/currencyConfig';
import { ToastService } from '../utils/toast.service';
export declare class CurrencyService {
    private consts;
    private connection;
    private toastr;
    private injector;
    private currencySubject;
    private updateSubject;
    private currencyListSubject;
    currency$: import("rxjs").Observable<CurrencyConfig>;
    update$: import("rxjs").Observable<Boolean>;
    currencyList$: import("rxjs").Observable<any[]>;
    private enableApplyCurrencyExchange;
    private getCurrencyListApi;
    private getConvertibilityApi;
    constructor(consts: Constants, connection: ConnectionService, toastr: ToastService, injector: Injector);
    /**
     * @description Se carga la moneda por defecto.
     */
    private loadDefaultCurrency;
    /**
     * @description calcula la convetibilidad del precio  pasado por paramentro segun esta formula:
     * **c = a * b** donde *c=moneda despues del cambio*, *a=valor que quiero cambiar* y *b=ratio de cambio*.
     * @param price Precio a cambiar
     * @param ratio Ratio de cambio
     * @returns Si el ratio no es null, retorna el precio cambiado, sino retorna el precio sin cambios.
     */
    calculateConvetibility: (price: any, ratio: any) => any;
    /**
     * @param code Codigo de moneda a la que se desea cambiar
     */
    setCurrency: (code: any) => Promise<void>;
    /**
     * @description Carga la lista de monedas/currencies.
     */
    private loadCurrencyList;
    /**
     * @description genera la carga y configuración de la moneda elegida para la conversion.
     * @param currency Moneda a convertir.
     */
    private loadCurrency;
    /**
     * @description Genera la convertibilidad de la moneda base a la nueva. Si baseCurrency no tiene valor
     * entonces utiliza la moneda base del canal.
     * @param currency Objeto de la moneda destino.
     * @param baseCurrency Codigo de la moneda base. *Ej: USD | ARS | EUR |...*
     */
    generateConvertibility: (currency: any, baseCurrency?: string) => Promise<void>;
    /**
     * @description Obtiene la conversion desde la moneda base a la destino. Recibe un objeto de tipo CurrencyConfig.
     * Si la conversion retorna resultado realiza el cambio, de lo contrario emite un mensaje de error.
     * @param baseCurrency Codigo de la moneda base.
     * @param targetCurrency Codigo de la moneda destino.
     */
    private getConvertibility;
    /**
     * @description Carga la moneda, si hay una en el localstorage toma esa y realiza la conversion.
     * de lo contrario solo setea en el observable currencySubject el valor por defecto cargado en las constantes.
     */
    private load;
}
