import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { Filter } from '../classes/filters/Filter';
import { DefaultFilter, FilterElement, FilterType } from '../interfaces/filter';
import { OptionsService } from './options.service';
export declare class FiltersService {
    private options;
    private route;
    private filtersSubject;
    private readySubject;
    filters$: Observable<Filter[]>;
    ready$: Observable<any>;
    constructor(options: OptionsService, route: Router);
    /**
     * @description Carga los filtros segun los datos recibidos por parametros.
     * @param filters Tipos de filtros, por defecto es 'all'
     * @param defaultFilters Filtros que se aplican por defecto
     * @param products Productos utilizados para armar los filtros dinamicos.
     * @returns {Observable<Filter[]>} Un observable de filtros.
     */
    loadFilters: (filters?: FilterType[], defaultFilters?: DefaultFilter[], products?: any) => Observable<Filter[]>;
    /**
     * @description Crea los filtros.
     * @param filters Tipos de filtros, por defecto es 'all'
     * @param defaultFilters Filtros que se aplican por defecto
     * @param products Productos utilizados para armar los filtros dinamicos.
     */
    setFilters: (filters: FilterType[], defaultFilters?: DefaultFilter[], products?: any) => void;
    /**
     * @description Fabrica de filtros segun el filtro.
     * @param filter
     * @param products
     * @returns
     */
    getFilterInstance: (filter: string, products?: any) => Filter;
    /**
     * @description retorna los filtros segun los tipos de filtros ingresado por parametros.
     * @param types Tipos de filtros => 'category' | 'attributes' | 'dynamics' | 'sort' | 'all'
     * @returns Arreglo de Filter
     */
    getSpecificFilters: (types: FilterType[]) => Filter[];
    /**
     * @description redirecciona segun la url del filtro.
     * @param filterElem No hace nada por ahora, es para mantener el mismo formato que como se usa en collection
     * @param data Filtro que se usa para redireccion
     */
    setFilterSelectedByPath: (filterElem: FilterElement, data: any) => void;
}
