import { Observable } from 'rxjs';
import { ConnectionService } from '../api/connection.service';
import { Constants } from '../core.consts';
import { PaginationService } from './pagination.service';
export declare class ReviewsService {
    private connection;
    private constants;
    private pagination;
    private reviewsSubject;
    reviews$: Observable<any>;
    reviewsByCodeApi: (code: any) => string;
    reviewsBySlugApi: (slug: any) => string;
    constructor(connection: ConnectionService, constants: Constants, pagination: PaginationService);
    /**
     * @description obtiene las reviews por el codigo del producto.
     * @param code codigo del producto
     * @returns
     */
    getReviewsByCode: (code: string) => Promise<void>;
    /**
     * @description actualiza las reviews por codigo
     * @param code codigo del producto
     * @returns
     */
    updateReviewsByCode: (code: string) => Promise<void>;
    /**
     * @description actualiza las reviews
     * @param res
     * @returns
     */
    updateReviews: (res: any) => void;
    /**
     * @description obtiene las reviews utilizando las url del atributo links de las reviews.
     * @param action self(defecto) | next | first | last
     * @returns
     */
    getReviews: (action?: string) => Promise<void>;
    /**
     * @description obtiene las reviews de una pagina en especial.
     * @param code codigo del producto
     * @param page número de pagina
     * @param limit cantidad limite de paginas
     * @returns
     */
    getReviewsByPage: (code: string, page: number, limit: number) => Promise<void>;
    /**
     * @description genera una url que sera utiliza como endpoint para pedir las reviews utilizando los datos
     * que viene en el atributo links.
     * 'next' => utiliza el atributo next de links
     * 'first' => utiliza el atributo first de links
     * 'last' => utiliza el atributo last de links
     * default => cualquier otro caso, utiliza el atributo self de links.
     * @param action next | first | last
     * @returns
     */
    private generateFinalApi;
    /**
     * @description obtiene las reviews de una pagina en especifico
     * @param code codigo del producto
     * @param page numero de pagina
     * @param limit cantidad limite de paginas
     * @returns
     */
    private generateFinalApiWithPage;
    /**
     * @description formatea la url que sera utilizada de endpoint para obtener las reviews
     * @param url
     * @returns
     */
    private formatUrl;
}
